import React, { useState } from "react";
import { Helmet } from 'react-helmet-async';
import {
  Github,
  Linkedin,
  Mail,
  MessageCircle,
  Smartphone,
  MapPin,
  Twitter,
  Copy,
  Check
} from "lucide-react";
import { motion } from "framer-motion";
import { cardStyles } from "@/features/shared/components/ui/card-styles";
import { siteConfig } from "@/features/shared/components/config/siteConfig";
import { useTheme } from "@/context/ThemeProvider";
import SEOHead from "@/features/shared/components/seo/SEOHead";

// Enhanced structured data for Contact page
const contactStructuredData = [
  {
    "@context": "https://schema.org",
    "@type": "Person",
    "name": "Chen Magled",
    "jobTitle": "Tech Lead & Full Stack Engineer",
    "url": "https://chenmagled.com",
    "email": "chen@chenmagled.com",
    "contactPoint": {
      "@type": "ContactPoint",
      "telephone": "+972-50-123-4567",
      "contactType": "professional",
      "availableLanguage": ["English", "Hebrew"]
    },
    "address": {
      "@type": "PostalAddress",
      "addressLocality": "Tel Aviv",
      "addressCountry": "Israel"
    },
    "sameAs": [
      "https://linkedin.com/in/chenmagled",
      "https://github.com/chenmagled",
      "https://twitter.com/chenmagled"
    ]
  }
];

export default function Contact() {
  const pageTitle = `Contact | ${siteConfig.name}`;
  const pageDescription = `Get in touch with Chen Magled. Find contact information via Email, LinkedIn, GitHub, Twitter, or see the location.`;
  const [copied, setCopied] = useState(null);
  const { theme } = useTheme();

  const contactMethods = [
    {
      icon: Mail,
      label: "Email",
      value: siteConfig.email,
      link: `mailto:${siteConfig.email}`,
      color: "#0066CC",
      darkColor: "#3B82F6",
      lightBg: "bg-blue-50",
      darkBg: "bg-blue-950/30"
    },
    // {
    //   icon: Smartphone,
    //   label: "WhatsApp",
    //   value: siteConfig.phone,
    //   link: `https://wa.me/${siteConfig.phone.replace(/[^0-9]/g, '')}`,
    //   color: "#25D366"
    // },
    {
      icon: Linkedin,
      label: "LinkedIn",
      value: "Connect on LinkedIn",
      link: siteConfig.social.linkedin,
      color: "#0A66C2",
      darkColor: "#0EA5E9",
      lightBg: "bg-sky-50",
      darkBg: "bg-sky-950/30"
    },
    {
      icon: Github,
      label: "GitHub",
      value: siteConfig.social.github.replace("https://github.com/", ""),
      link: siteConfig.social.github,
      color: "#24292F",
      darkColor: "#94A3B8",
      lightBg: "bg-slate-50",
      darkBg: "bg-slate-800/40"
    },
    {
      icon: Twitter,
      label: "Twitter",
      value: siteConfig.social.twitter.replace("https://twitter.com/", "@"),
      link: siteConfig.social.twitter,
      color: "#1DA1F2",
      darkColor: "#38BDF8",
      lightBg: "bg-cyan-50",
      darkBg: "bg-cyan-950/30"
    },
    {
      icon: MapPin,
      label: "Location",
      value: siteConfig.location,
      color: "#FF6B6B",
      darkColor: "#F87171", 
      lightBg: "bg-red-50",
      darkBg: "bg-red-950/30"
    }
  ];

  const handleCopy = (text, index) => {
    navigator.clipboard.writeText(text).catch(err => console.error("Could not copy text: ", err));
    setCopied(index);
    setTimeout(() => setCopied(null), 2000);
  };

  // Container variants for staggered animations
  const containerVariants = {
    hidden: { opacity: 0 },
    show: {
      opacity: 1,
      transition: {
        staggerChildren: 0.1
      }
    }
  };

  // Item variants for individual item animations
  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    show: { opacity: 1, y: 0, transition: { duration: 0.4 } }
  };

  return (
    <>
      <SEOHead
        structuredData={contactStructuredData}
        keywords={[
          "Contact Chen Magled",
          "Tech Lead consultation",
          "Full Stack Developer hire",
          "Cloud Engineering expert",
          "GenAI consultant",
          "Technical leadership services",
          "Software architecture consulting",
          "Enterprise development solutions",
          "AI integration specialist",
          "Technology consulting Tel Aviv"
        ]}
      />
      <div className="py-16 relative">
        <div className="absolute inset-0 overflow-hidden pointer-events-none">
          <div className="absolute inset-0 bg-grid-slate-200/50 dark:bg-grid-slate-700/20 [mask-image:linear-gradient(to_bottom,transparent,white,transparent)] opacity-20 dark:opacity-10"></div>
        </div>
        
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 relative">
          <motion.div
            initial={{ opacity: 0, y: -20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.5 }}
            className="max-w-5xl mx-auto"
          >
            <div className="text-center mb-8 sm:mb-12">
              <span className="inline-block px-4 py-2 rounded-full bg-primary/10 dark:bg-blue-800/30 text-primary dark:text-blue-400 text-sm font-medium mb-4 shadow-sm">
                Contact
              </span>
              <h1 className="text-3xl sm:text-4xl font-bold mb-4 text-slate-800 dark:text-white">Get In Touch</h1>
              <p className="text-base sm:text-lg text-slate-600 dark:text-gray-300 max-w-2xl mx-auto px-4">
                Have a question, project idea, or just want to connect? I'd love to hear from you!
              </p>
            </div>

            <div className="max-w-3xl mx-auto px-2 sm:px-0">
              <motion.div
                className="bg-white/90 dark:bg-gray-800/20 border border-slate-200 dark:border-gray-700/50 p-4 sm:p-6 lg:p-8 rounded-2xl shadow-lg backdrop-blur-sm"
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.5, delay: 0.2 }}
              >
                <h2 className="text-lg sm:text-xl font-semibold mb-6 sm:mb-8 flex items-center text-slate-800 dark:text-white">
                  <MessageCircle className="w-5 h-5 mr-2 text-primary dark:text-blue-400" aria-hidden="true" />
                  Ways to Connect
                </h2>
                
                <motion.div
                  className="grid gap-4 sm:gap-6"
                  variants={containerVariants}
                  initial="hidden"
                  animate="show"
                >
                  {contactMethods.map((method, i) => (
                    <motion.div
                      key={i}
                      variants={itemVariants}
                      whileHover={{
                        scale: 1.02,
                        transition: { duration: 0.2 }
                      }}
                      className="group flex flex-col sm:flex-row sm:items-center sm:justify-between rounded-xl p-4 sm:p-4 transition-all duration-300 bg-white dark:bg-gray-800/40 border border-slate-100 dark:border-gray-700/50 hover:border-slate-200 dark:hover:border-gray-600 shadow-sm hover:shadow"
                    >
                      <div className="flex items-center gap-4 mb-3 sm:mb-0">
                        <div
                          className={`p-3 rounded-xl ${method.lightBg} dark:${method.darkBg} flex-shrink-0`}
                        >
                          <method.icon
                            className="w-5 h-5"
                            style={{ color: theme === 'dark' ? method.darkColor : method.color }}
                            aria-hidden="true"
                          />
                        </div>
                        <div className="min-w-0 flex-1">
                          <p className="text-sm text-slate-500 dark:text-gray-400">{method.label}</p>
                          <p className="font-medium text-slate-800 dark:text-white break-words">{method.value}</p>
                        </div>
                      </div>
                      
                      <div className="flex gap-2 justify-end sm:justify-start">
                        {method.link && (
                          <a
                            href={method.link}
                            target="_blank"
                            rel="noopener noreferrer"
                            className="min-w-[44px] min-h-[44px] p-2 rounded-full hover:bg-slate-100 dark:hover:bg-gray-700 transition-colors flex items-center justify-center"
                            aria-label={`Open ${method.label}`}
                          >
                            <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="text-slate-600 dark:text-gray-300" aria-hidden="true">
                              <path d="M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6"></path>
                              <polyline points="15 3 21 3 21 9"></polyline>
                              <line x1="10" y1="14" x2="21" y2="3"></line>
                            </svg>
                          </a>
                        )}
                        
                        {method.label === "Email" && (
                          <button
                            onClick={() => handleCopy(method.value, i)}
                            className="min-w-[44px] min-h-[44px] p-2 rounded-full hover:bg-slate-100 dark:hover:bg-gray-700 transition-colors flex items-center justify-center"
                            aria-label={`Copy ${method.label}`}
                          >
                            {copied === i ? (
                              <Check className="w-4 h-4 text-green-500" />
                            ) : (
                              <Copy className="w-4 h-4 text-slate-500 dark:text-gray-400 hover:text-slate-800 dark:hover:text-white" />
                            )}
                          </button>
                        )}
                      </div>
                    </motion.div>
                  ))}
                </motion.div>
              </motion.div>

              <motion.div
                initial={{ opacity: 0 }}
                animate={{ opacity: 1 }}
                transition={{ duration: 0.5, delay: 0.6 }}
                className="text-center mt-6 sm:mt-8 p-4 sm:p-6 rounded-xl bg-blue-50/70 dark:bg-blue-900/10 text-blue-800 dark:text-blue-300 text-sm sm:text-base font-medium backdrop-blur-sm"
              >
                <p className="leading-relaxed">
                  Interested in working together? Send me a quick email at <a href={`mailto:${siteConfig.email}`} className="underline hover:text-blue-600 dark:hover:text-blue-200 transition-colors break-words">{siteConfig.email}</a>!
                </p>
              </motion.div>
            </div>
          </motion.div>
        </div>
      </div>
    </>
  );
}
